<?php

namespace App\Models;

use Illuminate\Database\Eloquent\Factories\HasFactory;
use Illuminate\Database\Eloquent\Model;
use Cviebrock\EloquentSluggable\Sluggable;


class Product extends Model
{
    use HasFactory;
    use Sluggable;
    protected $table = 'products';
    protected $fillable = [
        'name',
        'slug',
        'code',
        'category_id',
        'sub_category_id',
        'subsub_category_id',
        'product_tags',
        'brand',
        'price',
        'tax',
        'brand',
        'discount',
        'minimum_price',
        'maximum_price',
        'image',
        'description',
        'key_features',
        'specification',
        'meta_title',
        'meta_keyword',
        'meta_description',
    ];

    public function gallery()
    {
        return $this->hasMany(ProductImageGallery::class, 'product_id');
    }
    public function category()
    {
        return $this->belongsTo(Category::class, 'category_id');
    }
    public function subcategory()
    {
        //  return $this->belongsTo('App\Models\SubCategory', 'id');
        return $this->belongsTo(SubCategory::class, 'sub_category_id');
    }
    public function subsubcategory()
    {
        // return $this->belongsTo('App\Models\SubSubCategory', 'id');
        return $this->belongsTo(SubSubCategory::class, 'subsub_category_id');
    }
    public function brand()
    {
        return $this->belongsTo(Brand::class);
    }
    public function Promotion()
    {
        return $this->hasMany('App\Models\Promotion', 'product_id');
    }
    public function stock()
    {
        return $this->hasMany('App\Models\Stock', 'product_id');
    }

    public function order()
    {
        return $this->hasMany('App\Models\OrderedProduct', 'product_id');
    }
    public function cart()
    {
        return $this->hasMany('App\Models\Cart', 'product_id');
    }
    public function returnProduct()
    {
        return $this->hasOne(ReturnedOrder::class, 'product_id');
    }

    public function productDeliveryAreas()
    {
        return $this->hasMany(DeliveryAreas::class, 'product_id');
    }

      public function sluggable(): array
    {
        return [
            'slug' => [
                'source' => 'title'
            ]
        ];
    }
}
