<?php

namespace App\Models;

use Illuminate\Contracts\Auth\MustVerifyEmail;
use Illuminate\Database\Eloquent\Factories\HasFactory;
use Illuminate\Foundation\Auth\User as Authenticatable;
use Illuminate\Notifications\Notifiable;
use Laravel\Sanctum\HasApiTokens;
use Cviebrock\EloquentSluggable\Sluggable;

class User extends Authenticatable
{
    use HasApiTokens, HasFactory, Notifiable;
    use Sluggable;
    /**
     * The attributes that are mass assignable.
     *
     * @var array<int, string>
     */
    protected $fillable = [
        'user_type_id',
        'name',
        'slug',
        'email',
        'password',
        'phone_number',
        'shop_name',
        'logo',
        'shop_address',
        'shop_info',
        'alternative_mobile_number',
        'dob',
        'gender',
        'city',
        'country',
        'zipcode',
        'office_address',
        'residence_address',
        'photo',
        'id_proof',
        'commission_rate'
    ];

    /**
     * The attributes that should be hidden for serialization.
     *
     * @var array<int, string>
     */
    protected $hidden = [
        'password',
        'remember_token',
    ];

    /**
     * The attributes that should be cast.
     *
     * @var array<string, string>
     */
    protected $casts = [
        'email_verified_at' => 'datetime',
    ];

    public function usertype()
    {
        return $this->belongsTo(UserType::class, 'user_type_id');
    }
    public function stock()
    {
        return $this->hasMany('App\Models\Stock', 'vendor_id');
    }
    public function vendorOrders()
    {
        return $this->hasMany('App\Models\Order', 'vendor_id');
    }
    public function order()
    {
        return $this->hasMany(SalePersonOrder::class, 'vendor_id');
    }
    public function salesperson()
    {
        return $this->hasMany(SalePersonOrder::class, 'salesperson_id ');
    }
    public function commission()
    {
        return $this->hasMany('App\Models\Commission', 'vendor_id');
    }

      public function sluggable(): array
    {
        return [
            'slug' => [
                'source' => 'title'
            ]
        ];
    }
}
